@@ -126,6 +126,9 @@ class Run:
         _custom = [{"key": k, "value": v} for k, v in self.lastData.items()]
         data = {
             "runId": self.run_id,
+            "runName": self.run_name,
+            "expName": self.exp_name,
+            "teamName": self.team_name,
             "summary": {
                 "_runtime": time.time() - self.run_start_time,
                 "_step": self.log_step,
